@@ -12,11 +12,12 @@ Version 0.9
 
 =cut
 
-our $VERSION = '0.9_200';
+our $VERSION = '0.9';
 
 
 =head1 SYNOPSIS
 
+
 This is inteded to read and sort dicom images created by medical imaging devices.
 
 Either use something like the following from within your module/application
@@ -59,31 +60,18 @@ Piddles are created for each lProtID or Series Number value.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 is_equal ($dcm1,$dcm2,$pattern)
+=head2 read_text_hdr
 
-This is used to check if two dicoms can be stacked based on matrix size, orientation and pixel spacing.
+parses the ASCCONV part of Siemens data header into the ascconv field of the
+piddle header. All special characters except [a-z0-9]i are converted to _ -- no
+quoting of hash keys required!
 
-If $pattern matches /d/, only dims are checked
-
-=head2 load_dcm_dir ( $dir,\%options)
+=head2 load_dcm_dir
 
 reads all dicom files in a dicrectory and returns a hash of piddles containing
-sorted N-D data sets. 
-
-Fields in the options hash include:
-
-=over 
-
-=item id: 
-
-Uses a code reference to access the field by which to split. See read_dcm.pl for details. Currently, the ascconv field lProtID or dicom Series Number are used as keys. 
-
-=item sp: 
-
-Split slice groups, otherwise they are stacked together if xy-dims match, even transposed.
-
-=back 
-
+sorted N-D data sets. Uses a code reference to access the field by which to split.
+See read_dcm.pl for details. Currently, the ascconv field lProtID or dicom Series Number are
+used as keys. 
 
 =head2 parse_dcms 
 
@@ -95,21 +83,11 @@ based on lProtID and the ICE_Dims field in 0029_1010. Returns a hash of piddles
 
 unpacks dicom fields and walks subfield structures recursively.
 
-=head2 sort_series
 
-Groups dicom files based on their series number. If data within the series
-don't fit, the outcome depends on the split option. If set, it will always
-produce several piddles, appending a, b, c, etc.; if not, transposition is tried, 
-ignoring Pixel Spacing and Image Rotation. Only if this fails, data is split.
-
-=head2 read_dcm ($file, \%options)
+=head2 read_dcm
 
 reads a dicom file and creates a piddle-with-header structure.
 
-=head2 printStruct
-
-This is used to generate human readable and parsable text from the headers.
-
 =head1 TODO 
 
 write tests! 
@@ -130,67 +108,34 @@ use Exporter;
 #use PDL::IO::Nifti;
 use strict;
 #use PDL::IO::Sereal;
-#use 5.10.0;
+use 5.10.0;
 
 our @ISA=qw/Exporter/;
-our @EXPORT_OK=qw/read_dcm parse_dcms load_dcm_dir printStruct/;
+our @EXPORT_OK=qw/read_text_hdr read_dcm parse_dcms load_dcm_dir/;
 
 my @key_list=("Instance Number",,'Window Center','Content Time',
 	'Nominal Interval','Instance Creation Time','Largest Image Pixel Value',
 	'Trigger Time','Window Width','Acquisition Time','Smallest Image Pixel Value',
 );
 
+sub read_text_hdr {
+    my $f=shift; # File
+    my $self=shift;
+    open (HDR,'<',\$f) || die "no header !";
+    my $l;
+    #say "file $f line $l";
+    do {$l=<HDR>; } until ($l=~/ASCCONV BEGIN/);
+    while (($l=<HDR>)!~/ASCCONV END/) {
+        chomp $l;
+        if ( $l) {
+            chomp (my ($key,$val)=split /\s*=\s*/,$l);
+            chomp($key);
+            $key=~s/[\[\].]/_/g;
+            $self->hdr->{ascconv}->{$key}=$val;
+        }
+    }
+    close HDR;
 
-sub sort_series {
-	my $ret=$_[0]->hdr->{dicom}->{"Series Number"}; 
-	$ret=~ s/^\s+|\s+$//g; $ret;
-}
-
-# copied and modified from stackoverflow or perlmonks thread (can't remember atm)
-sub printStruct {
-	my ($struct,$structName,$pre)=@_;
-#    print "-----------------\n" unless (defined($pre));
-#   
-	my $res;
-	#if (!ref($struct)){ # $struct is a scalar.
-	if (ref($struct) eq "ARRAY") { # Struct is an array reference
-#return ("ARRAY(".scalar(@$struct).")") if (@$struct>100);
-		for(my$i=0;$i<@$struct;$i++) {
-			if (ref($struct->[$i]) eq "HASH") {
-				$res.=printStruct($struct->[$i],$structName."->[$i]",$pre." ");
-			} elsif (ref($struct->[$i]) eq "ARRAY") { # contents of struct is array ref
-				$res.= "$structName->"."[$i]: ()\n" if (@{$struct->[$i]}==0);
-				my $string = printStruct($struct->[$i],$structName."->[$i]",$pre." ");
-				$res.= "$structName->"."[$i]: $string\n" if ($string);
-			} elsif (ref($struct->[$i]) eq "PDL") { # contents of struct is array ref
-				$res.= "$structName->"."[$i]: ".(join (' ',list ($struct->[$i])))."\n";
-			} else { # contents of struct is a scalar, just print it.
-				
-				$res.= "$structName->"."[$i]: $struct->[$i]\n";
-			}
-		}
-		#return($res);
-	} elsif (ref($struct) eq "HASH"){ # $struct is a hash reference or a scalar
-		foreach (sort keys %{$struct}) {
-			if (ref($struct->{$_}) eq "HASH") {
-				$res.=printStruct($struct->{$_},$structName."->{$_}",$pre." ");
-			} elsif (ref($struct->{$_}) eq "ARRAY") { # contents of struct is array ref
-				my $string = printStruct($struct->{$_},$structName."->{$_}",$pre." ");
-				$res.= "$structName->"."{$_}: $string\n" if ($string);
-			} elsif (ref($struct->{$_}) eq "PDL") { # contents of struct is array ref
-				$res.= "$structName->"."{$_}: ".(join (' ',list($struct->{$_})))."\n";
-			} else { # contents of struct is a scalar, just print it.
-				$res.= "$structName->"."{$_}: $struct->{$_}\n";
-			}
-		}
-		#return($res);
-	} elsif (ref ($struct) eq 'PDL') {
-		$res.= "$structName: ".(join (' ',list($struct)))."\n";
-	} else {
-		$res.= "$structName: $struct\n";
-	} 
-#print "------------------\n" unless (defined($pre));
-	return($res);
 }
 
 sub unpack_field{ 
@@ -237,22 +182,26 @@ sub unpack_field{
 
 sub read_dcm {
 	my $file=shift;
-	my $opt=shift; #options
 	my $dcm=DicomPack::IO::DicomReader->new($file) || return; 
 	my $h=unpack('S',substr ($dcm->getValue('Rows','native'),3,2));
 	my $w=unpack('S',substr ($dcm->getValue('Columns','native'),3,2));
 	my $data=$dcm->getValue('PixelData','native');
-	return (undef ) unless defined $data;
 	my $datatype= (substr($data,0,2));
-	#say "datatype $datatype";
+	say "datatype $datatype";
 	my $pdl=zeroes(ushort,$w,$h) if ($datatype =~/OW|XX/); 
 	$pdl->make_physical;
 	${$pdl->get_dataref}=substr($data,3);
 	$pdl->upd_data;
+	#say "Rows $h";
+	read_text_hdr($dcm->getValue ('0029,1020','native'),$pdl); # The protocol is in here
 	$pdl->hdr->{raw_dicom}=$dcm->getDicomField;
-	no PDL::NiceSlice;
-	#say "populate header ",$$opt{dims},join ' ',%{$opt};
-	my $dims=$$opt{dims}->($dcm,$pdl); # call to vendor/modality specific stuff
+	delete $pdl->hdr->{raw_dicom}->{'0029,1020'}; # Protocol
+	#delete $pdl->hdr->{raw_dicom}->{'0029,1010'}; # also big structure, not sure what
+		# Ice Dimension string: 13 numbers or X=undef
+	#say "Ice Dims ",$dcm->getValue('0029,1010','native')=~/ICE_Dims/;
+	my @d=$dcm->getValue('0029,1010','native')=~/ICE_Dims.{92}((_?(X|\d+)){13})/s; 
+	my $dims=shift @d;
+	#say "Raw Dims @d";
 	$pdl->hdr->{IceDims}=$dims || die "No Ice Dims ",$file; #pdl->hdr->{raw_dicom}->{'0029,1010'}; #[split '_',$dims{$pid}=~s/X/0/r];
 	delete $pdl->hdr->{raw_dicom}->{'7fe0,0010'}; # Pixel data
 	for my $id (keys %{$pdl->hdr->{raw_dicom}}) {
@@ -272,94 +221,39 @@ sub read_dcm {
 		$pdl->hdr->{dicom}->{$id} #=~s/([0-9a-fA-F]{4}),([0-9a-fA-F]{4})/$1_$2/r}
 			=$value;
 	} # for loop over dicom ids
-	delete $pdl->hdr->{raw_dicom} if $$opt{delete_raw};
 	return $pdl;
 }
-sub is_equal {
-	my $a=shift;
-	my $b=shift;
-	my $opt=shift;
-	#say "dims ", any $a->shape-$b->shape,', ', # they have equal dimensions
-		#"spacing ",$a->hdr->{dicom}->{'Pixel Spacing'} ,' ne ', $b->hdr->{dicom}->{'Pixel Spacing'},', ',
-		#"orientation ",$a->hdr->{dicom}->{'Image Orientation (Patient)'} ,' ne ', $b->hdr->{dicom}->{'Image Orientation (Patient)'};
-	return if (any ($a->shape-$b->shape)); # they have equal dimensions
-	#say "is_equal: dims ok";
-	return 1 if ($opt =~/d/);
-	return if $a->hdr->{dicom}->{'Pixel Spacing'} ne $b->hdr->{dicom}->{'Pixel Spacing'};
-	#say "is_equal: spacing ok";
-	return if $a->hdr->{dicom}->{'Image Orientation (Patient)'} ne $b->hdr->{dicom}->{'Image Orientation (Patient)'};
-	#say "is_equal: orientation ok";
-	1;
-}
 
 sub load_dcm_dir {
 	my %dcms; #([]);
 	my @pid;
 	my $dname=shift;
 	my %dims; 
-	my $opt=shift; # field by which to split
-	my $id=$$opt{id};
-	my $sp=$$opt{split};
+	my $id=shift; # field by which to split
 	my $n=0;
-	my %refs; # reference images for each stack
 	opendir (my $dir, $dname) ||die "cannot open directory!";
 	for my $file (readdir ($dir)) {
 		next unless (-f "$dname/$file"); # =~m/\.dcm$|\.IMA$/;
 		#say "file $file";
-		my $p=read_dcm("$dname/$file",$opt);
+		my $p=read_dcm("$dname/$file");
 		eval{$p->isa('PDL')} ||next;
 		$n++;
+		#my $pid=$p->hdr->{ascconv}->{lProtID};
 		no PDL::NiceSlice;
-		my $pid=$id->($p); # Call to subroutine reference 
-		#say "ID $pid Instance number ",$p->hdr->{dicom}->{'Instance Number'};
-		$dcms{$pid}={} unless ref $dcms{$pid};
-		my $ref =$refs{$pid}; 
-		#say "ref ID: ",$id->($ref)," ref Instance number ",$ref->hdr->{dicom}->{'Instance Number'},
-			#$ref->info,$p->info, "diff? ",is_equal($ref,$p);
-		if (defined $ref) {
-		unless ( is_equal($ref,$p )) {
-			if ( !$sp and is_equal($ref,$p->transpose,'d')) {
-				#say "Split? $sp; ", ( !$sp and is_equal($ref,$p->transpose,'d'));
-				$p->hdr->{tp}=1;
-			} else {
-				#say "Difference! $sp";
-				my $flag=0;
-				my $n='a';
-				my $nid;
-				do {
-					$nid=$id->($p).$n;
-					if (ref $dcms{$nid} eq 'HASH'){ # group
-						for my $r2 (values %{$dcms{$nid}}){
-							$flag=is_equal($r2,$p);
-					#		say "r2 vs. p id $nid ",$r2->info,$p->info;
-							last unless $flag;
-						}
-					} else {
-						$dcms{$nid}={};
-						$pid=$nid;
-						$flag=1;
-					}
-					$n++;
-				} until $flag;
-				$pid=$nid;
-			}
-		}
-		} # defined $ref
+		my $pid=$id->($p); 
 		use PDL::NiceSlice;
-		unless (grep (/^$pid$/,@pid)) {
-			#say "PID: $pid";
+		#say "PID: $pid @pid";
+		unless (grep (/$pid/,@pid)) {
 			$dims{$pid}=zeroes(short,13);
 			push @pid,$pid;
-			$refs{$pid}=$p;
 		}
-		#say "pos ",$p->hdr->{dicom}->{'0020,0032'}=~s/\\/ /r;
-		#say "orientation ",$p->hdr->{dicom}->{'0020,0037'}=~s/\\/ /r;
-		#say "Spacing ",$p->hdr->{dicom}->{'0028,0030'}=~s/\\/ /r;
+		$dcms{$pid}={} unless ref $dcms{$pid};
+		say "pos ",$p->hdr->{dicom}->{'0020,0032'}=~s/\\/ /r;
+		say "orientation ",$p->hdr->{dicom}->{'0020,0037'}=~s/\\/ /r;
+		say "Spacing ",$p->hdr->{dicom}->{'0028,0030'}=~s/\\/ /r;
 #say "IceDims ",$p->hdr->{IceDims};
-		#say "$n Series $pid IceDims ",$p->hdr->{IceDims};
-		(my $str=$p->hdr->{IceDims})=~s/X/1/e;
-		my @d=split ('_',$str);
-		my $iced=pdl(short,@d); #badvalue(short)/er)]);
+		say "$n Series $pid IceDims ",$p->hdr->{IceDims};
+		my $iced=pdl(short,[split ('_',$p->hdr->{IceDims}=~s/X/1/er)]); #badvalue(short)/er)]);
 		#say "$file IceDims ",$iced;
 #$iced->badflag(1);
 		$dims{$pid}.=$dims{$pid}*($dims{$pid}>=$iced)+$iced*($iced>$dims{$pid});
@@ -367,124 +261,89 @@ sub load_dcm_dir {
 		$dcms{$pid}->{$p->hdr->{IceDims}}=$p; # if ($p->isa('PDL')); # and $pid == $p->hdr->{ascconv}->{lProtID});
 	}
 	for my $id (@pid) {
-		$dcms{$id}->{dims}=$dims{$id}->copy;
-		print "Set dims: id $id, $dims{$id}\n";
+		$dcms{$id}->{dims}=dclone $dims{$id};
 	}
 	\%dcms;
 }
 
-
-
 sub parse_dcms {
 	my %dcms=%{shift()}; # reference to hash of 
 	my %data;
 	#my (%tes,);
-	for my $pid (sort keys %dcms) {
+	for my $pid (keys %dcms) {
 		my %stack=%{$dcms{$pid}};
-		#next unless (ref $stack{dims} eq 'HASH');
-		#say keys %stack;
-		my $dims =$stack{dims};
-		die "No dims $pid " unless eval {$dims->isa('PDL')};
+		my $dims =dclone $stack{dims};
 		delete $stack{dims};
 		my $ref=$stack{(keys %stack)[0]};
 		#my $z=$ref->hdr->{ascconv}->{sSliceArray_lSize};
 		my $x=$ref->hdr->{dicom}->{Columns} ; 
 		die "No $x ",$ref->info unless $x;
 		my $y=$ref->hdr->{dicom}->{Rows};
-		#print "ID: $pid dims $dims transpose? ",$ref->hdr->{tp},"\n";
+		#my $echoes=$ref->hdr->{ascconv}->{lContrasts};
+		#my $t=$ref->hdr->{ascconv}->{lRepetitions}+1;
+		#for my $i (0..$echoes-1) {
+		#	$tes{$ref->hdr->{ascconv}->{"alTE\_$i\_"}}=$i;
+		#}
+		#my ($ncoils,@coils);
+		#if (defined ($ref->hdr->{dicom}->{"0051,100f"}) 
+		#		and $ref->hdr->{dicom}->{"0051,100f"}=~/^C:/ ) {
+		#	@coils=map {$ref->hdr->{ascconv}->$_ } 
+		#	grep {/asCoilSelectMeas_0__asList_\d+__lElementSelected/}
+		#	keys %{$ref->hdr->{ascconv}}; #{ } @{$conv{$pid}};
+		#	$ncoils=@coils;
+		#} else {
+		#	$ncoils=1;
+		#}
+#my $other=(@stack/$z,$t,$echoes/$ncoils);
+#my $data{$pid}=zeroes(ushort,$x,$y,$z,$echoes,$ncoils,$t,$other);
+		say "Creating piddle $x,$y, $dims";
 		# dims: coil echo phase set t ? partition? slice? ? slice ? some_id
 		my $order=pdl[6,7,4,1,0,2,3];
-		if ($ref->hdr->{tp}) { $data{$pid}=zeroes(ushort,$y,$x,$dims($order));}
-		else { $data{$pid}=zeroes(ushort,$x,$y,$dims($order));}
-		my $header=dclone($ref->gethdr); # populate the header
-		$header->{diff}={};
-		$header->{Dimensions}=[qw/x y z t echo channel set/];
+		$data{$pid}=zeroes(ushort,$x,$y,$dims($order));
+		$data{$pid}->sethdr(dclone($ref->gethdr)); # populate the header
+		$data{$pid}->hdr->{diff}={};
+		$data{$pid}->hdr->{Dimensions}=[qw/x y z t echo channel set/];
 		for my $key (@key_list) {
-			$header->{dicom}->{$key}=zeroes(list $dims($order));
-			#$header->{dicom}->{$key}.=$ref->hdr->{dicom}->{$key};
-			#say "$key ",$header->{dicom}->{$key}->info;
+			$data{$pid}->hdr->{dicom}->{$key}=zeroes(list $dims($order));
+			#$data{$pid}->hdr->{dicom}->{$key}.=$ref->hdr->{dicom}->{$key};
+			say "$key ",$data{$pid}->hdr->{dicom}->{$key}->info;
 		}
-		$header->{dicom}->{'Image Orientation (Patient)'}=zeroes(6,list $dims($order));
-		$header->{dicom}->{'Image Position (Patient)'}=zeroes(3,list $dims($order));
-		$header->{dicom}->{'Pixel Spacing'}=zeroes(2,list $dims($order));
+		$data{$pid}->hdr->{dicom}->{'Image Orientation (Patient)'}=zeroes(6,list $dims($order));
+		$data{$pid}->hdr->{dicom}->{'Image Position (Patient)'}=zeroes(3,list $dims($order));
+		$data{$pid}->hdr->{dicom}->{'Pixel Spacing'}=zeroes(2,list $dims($order));
 		for my $dcm (values %stack) {
 			#say $data{$pid}->info,list( $dcm->hdr->{IcePos}->($order));
-			#say "$x $y ",$ref->info;
-			#say "ID $pid: Transpose? ",$dcm->hdr->{tp},$dcm->info;
-			if ($dcm->hdr->{tp}) {
-				$data{$pid}->(,,list $dcm->hdr->{IcePos}->($order)).=$dcm->transpose;}
-			else {$data{$pid}->(,,list $dcm->hdr->{IcePos}->($order)).=$dcm;}
+			$data{$pid}->(,,list $dcm->hdr->{IcePos}->($order)).=$dcm;
 			for my $key (@key_list) {
 				#say "setting $key ",$dcm->hdr->{IcePos}->($order) ;
-				$header->{dicom}->{$key}->(list $dcm->hdr->{IcePos}->($order))
+				$data{$pid}->hdr->{dicom}->{$key}->(list $dcm->hdr->{IcePos}->($order))
 					.=$dcm->hdr->{dicom}->{$key};
 			}
-			$header->{dicom}->{'Image Orientation (Patient)'}
+			$data{$pid}->hdr->{dicom}->{'Image Orientation (Patient)'}
 				->(,list $dcm->hdr->{IcePos}->($order))
 				.=pdl (split /\\/,$dcm->hdr->{dicom}->{'Image Orientation (Patient)'});
-			$header->{dicom}->{'Pixel Spacing'}
+			$data{$pid}->hdr->{dicom}->{'Pixel Spacing'}
 				->(,list $dcm->hdr->{IcePos}->($order))
 				.=pdl (split /\\/,$dcm->hdr->{dicom}->{'Pixel Spacing'});
-			$header->{dicom}->{'Image Position (Patient)'}
+			$data{$pid}->hdr->{dicom}->{'Image Position (Patient)'}
 				->(,list $dcm->hdr->{IcePos}->($order))
 				.=pdl (split /\\/,$dcm->hdr->{dicom}->{'Image Position (Patient)'});
 			for my $field (keys %{$dcm->hdr->{dicom}}) {
 				if ($dcm->hdr->{dicom}->{$field} ne $ref->hdr->{dicom}->{$field}) {
-					$header->{diff}->{$field}={}
-						unless ref ($header->{diff}->{$field});
-					$header->{diff}->{$field}->{$dcm->hdr->{IceDims}}=
+					$data{$pid}->hdr->{diff}->{$field}={}
+						unless ref ($data{$pid}->hdr->{diff}->{$field});
+					$data{$pid}->hdr->{diff}->{$field}->{$dcm->hdr->{IceDims}}=
 						$dcm->hdr->{dicom}->{$field};
 				}
 			}
-		} # for ... values %stack
-		my $ind=whichND(maxover maxover ($data{$pid})); # actually populated fields!
-		#$data{$pid}->hdrcpy(1);
-		for my $ax (0..$ind->dim(0)-1) {
-			$data{$pid}=$data{$pid}->dice_axis($ax+2,$ind($ax)->uniq); # compact the data!
-			$header->{dicom}->{'Image Position (Patient)'}
-				=$header->{dicom}->{'Image Position (Patient)'}->dice_axis($ax+1,$ind($ax)->uniq); 
-		$header->{dicom}->{'Image Orientation (Patient)'}
-			=$header->{dicom}->{'Image Orientation (Patient)'}->dice_axis($ax+1,$ind($ax)->uniq);
-		$header->{dicom}->{'Pixel Spacing'}
-			=$header->{dicom}->{'Pixel Spacing'}->dice_axis($ax+1,$ind($ax)->uniq);
-			for my $key (@key_list) {
-				$header->{dicom}->{$key}=$header->{dicom}->{$key}->dice_axis($ax,$ind($ax)->uniq);
-			}
-			for my $val (values %{$header->{diff}}) {
-				$val=$val->dice_axis($ax,$ind($ax)->uniq) if (ref ($val) =~ /PDL/);
-			}
 		}
-		#$data{$pid}->hdrcpy(0);
-		#say "ind $ind";
-		#say "position ",$header->{dicom}->{'Image Position (Patient)'}->info;
-		#say "orientationn ",$header->{dicom}->{'Image Orientation (Patient)'}->info;
-		#say "spacing ",$header->{dicom}->{'Pixel Spacing'}->info;
-		$header->{dicom}->{'Image Position (Patient)'}
-			=$header->{dicom}->{'Image Position (Patient)'}->clump(1,2)->clump(5,6)->copy;
-		$header->{dicom}->{'Image Orientation (Patient)'}
-			=$header->{dicom}->{'Image Orientation (Patient)'}->clump(1,2)->clump(5,6)->copy;
-		$header->{dicom}->{'Pixel Spacing'}
-			=$header->{dicom}->{'Pixel Spacing'}->clump(1,2)->clump(5,6)->copy;
-		#say "A position ",$header->{dicom}->{'Image Position (Patient)'}->info;
-		#say "A orientationn ",$header->{dicom}->{'Image Orientation (Patient)'}->info;
-		#say "A spacing ",$header->{dicom}->{'Pixel Spacing'}->info;
-		for my $key (@key_list) {
-			#say "key $key ",$header->{dicom}->{$key}->info;
-			$header->{dicom}->{$key}=$header->{dicom}->{$key}->clump(0,1)->clump(4,5);
-		}
-		for my $val (values %{$header->{diff}}) {
-			$val=$val->clump(0,1)->clump(4,5) if (ref ($val) =~ /PDL/);
-		}
-		#say "The following keys differ from ref:\n\t",join ", ",sort keys (%{$header->{diff}});
-		#say Dumper $header->{diff};
+		#say "The following keys differ from ref:\n\t",join ", ",sort keys (%{$data{$pid}->hdr->{diff}});
+		#say Dumper $data{$pid}->hdr->{diff};
 		#say $data{$pid}->info;
-		#say $header->{dicom}->{Rows};
-		#$data{$pid}->hdrcpy(1);
+		#say $data{$pid}->hdr->{dicom}->{Rows};
+		$data{$pid}->hdrcpy(1);
 		# serialise partitions/slices and phases/sets
 		$data{$pid}=$data{$pid}->clump(2,3)->clump(6,7);
-		$data{$pid}->sethdr(dclone($header));
-		#say "ID $pid ",$data{$pid}->hdr->{dicom}->{'Pixel Spacing'}->squeeze;
-		#say $data{$pid}->info;
 		#say $data{$pid}->info;
 		#say $data{$pid}->hdr->{dicom}->{Rows};
 	} # for my $pid ...
